summaryrefslogtreecommitdiff
path: root/sys/arch/sparc64
diff options
context:
space:
mode:
authorMartin Pieuchot <mpi@cvs.openbsd.org>2016-02-27 13:08:08 +0000
committerMartin Pieuchot <mpi@cvs.openbsd.org>2016-02-27 13:08:08 +0000
commitb2f97f2ae592bb15002759d8300624750ab10eff (patch)
tree516aba0f8239ca6eb161284d94ceaf4b10b74d6d /sys/arch/sparc64
parent8115b491c372ec13e6406e31e006f1924e62218b (diff)
Rename kdb_trap() into db_ktrap().
The goal is to include it in the list of functions that must not be instrumented. All ddb(8) functions should be in this list and have their names start with 'db_'. ok visa@, deraadt@
Diffstat (limited to 'sys/arch/sparc64')
-rw-r--r--sys/arch/sparc64/include/db_machdep.h4
-rw-r--r--sys/arch/sparc64/sparc64/db_interface.c8
-rw-r--r--sys/arch/sparc64/sparc64/trap.c6
3 files changed, 9 insertions, 9 deletions
diff --git a/sys/arch/sparc64/include/db_machdep.h b/sys/arch/sparc64/include/db_machdep.h
index 8985fd287f2..96398636d09 100644
--- a/sys/arch/sparc64/include/db_machdep.h
+++ b/sys/arch/sparc64/include/db_machdep.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: db_machdep.h,v 1.15 2015/08/28 23:28:39 kettenis Exp $ */
+/* $OpenBSD: db_machdep.h,v 1.16 2016/02/27 13:08:07 mpi Exp $ */
/* $NetBSD: db_machdep.h,v 1.12 2001/07/07 15:16:13 eeh Exp $ */
/*
@@ -132,7 +132,7 @@ void db_machine_init(void);
#define DB_MACHINE_COMMANDS
void db_machine_init(void);
-int kdb_trap(int, struct trapframe64 *);
+int db_ktrap(int, struct trapframe64 *);
int db_enter_ddb(void);
void db_startcpu(struct cpu_info *);
diff --git a/sys/arch/sparc64/sparc64/trap.c b/sys/arch/sparc64/sparc64/trap.c
index adc0aa89617..ec524140c70 100644
--- a/sys/arch/sparc64/sparc64/trap.c
+++ b/sys/arch/sparc64/sparc64/trap.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: trap.c,v 1.87 2015/11/06 06:33:26 guenther Exp $ */
+/* $OpenBSD: trap.c,v 1.88 2016/02/27 13:08:07 mpi Exp $ */
/* $NetBSD: trap.c,v 1.73 2001/08/09 01:03:01 eeh Exp $ */
/*
@@ -371,13 +371,13 @@ trap(tf, type, pc, tstate)
#ifdef DDB
if (type == T_BREAKPOINT) {
write_all_windows();
- if (kdb_trap(type, tf)) {
+ if (db_ktrap(type, tf)) {
/* ADVANCE; */
return;
}
}
if (type == T_PA_WATCHPT || type == T_VA_WATCHPT) {
- if (kdb_trap(type, tf)) {
+ if (db_ktrap(type, tf)) {
/* DDB must turn off watchpoints or something */
return;
}
diff --git a/sys/arch/sparc64/sparc64/db_interface.c b/sys/arch/sparc64/sparc64/db_interface.c
index 250c64a9ada..2ff4a2a9632 100644
--- a/sys/arch/sparc64/sparc64/db_interface.c
+++ b/sys/arch/sparc64/sparc64/db_interface.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: db_interface.c,v 1.39 2015/08/28 23:28:39 kettenis Exp $ */
+/* $OpenBSD: db_interface.c,v 1.40 2016/02/27 13:08:07 mpi Exp $ */
/* $NetBSD: db_interface.c,v 1.61 2001/07/31 06:55:47 eeh Exp $ */
/*
@@ -256,15 +256,15 @@ kdb_kbd_trap(tf)
{
if (db_active == 0 /* && (boothowto & RB_KDB) */) {
printf("\n\nkernel: keyboard interrupt tf=%p\n", tf);
- kdb_trap(-1, tf);
+ db_ktrap(-1, tf);
}
}
/*
* kdb_trap - field a TRACE or BPT trap
*/
int
-kdb_trap(type, tf)
+db_ktrap(type, tf)
int type;
register struct trapframe64 *tf;
{
@@ -256,15 +256,15 @@ kdb_kbd_trap(tf)
}
/*
- * kdb_trap - field a TRACE or BPT trap
+ * db_ktrap - field a TRACE or BPT trap
*/
int